/*
 * @Author: Zhang zhixing
 * @Date: 2022-08-01 22:00:10
 * @LastEditors: Zhang zhixing
 * @LastEditTime: 2022-08-02 11:03:33
 * @FilePath: /zzx-cli/lib/core/action.js
 * @Description:
 *
 * Copyright (c) 2022 by Zhang zhixing, All Rights Reserved.
 */
// promisify 将回调转成promise
const { promisify } = require('util')
const program = require('commander')
const download = promisify(require('download-git-repo'))
const chalk = require('chalk')
const open = require('open')
const { vueRepo } = require('../config/repo-config')
const { commandSpawn } = require('../utils/terminal')
const { hint, error } = require('../utils/log')

const createProjectAction = async (project) => {
  hint('git clone start...')
  // 1. clone 项目
  try {
    await download(vueRepo, project, { clone: true })
  } catch (e) {
    error('clone a respository error with:' + e)
  }
  // 2. 执行npm install
  const command = process.platform === 'win32' ? 'npm.cmd' : 'npm'
  await commandSpawn(command, ['install'], { cwd: `./${project}` })

  // 3. 运行npm run serve
  commandSpawn(command, ['run', 'serve'], { cwd: `./${project}` })
  // 4. 打开浏览器
  open('http://localhost:8080/')
}

module.exports = {
  createProjectAction
}
